@@ -74,8 +74,7 @@ class DataLake():
                     orient="records",
                     lines=True,
                     compression="gzip",
-                    storage_options=None if self.session.profile_name is None else {
-                        "profile": self.session.profile_name}
+                    storage_options={"profile": self.session.profile_name}
                 )
             elif file_format == "parquet":
                 object_name = self.object_name_prefix + \
@@ -86,8 +85,7 @@ class DataLake():
                         object_name=object_name,
                     ),
                     compression='gzip',
-                    storage_options=None if self.session.profile_name is None else {
-                        "profile": self.session.profile_name}
+                    storage_options={"profile": self.session.profile_name}
                 )
             else:
                 logging.error("FILE FORMAT {file_format} NOT SUPPORTED".format(
@@ -150,8 +148,7 @@ class DataLake():
                             orient="records",
                             lines=True,
                             compression="gzip" if ".gzip" in object.get('Key') else "infer",
-                            storage_options=None if self.session.profile_name is None else {
-                                "profile": self.session.profile_name}
+                            storage_options={"profile": self.session.profile_name}
                         )
                         data = pandas.concat([data, file_data])
 
